<?php
/**
 * Link functions
 *
 * Package Manduca
 *
 * @since 17.9.6
 * */


/*
 * Make hungarian definite article ('a' or 'az')
 *
 * depending on the input
 *
 * &paramter $word : word to get the article;
 *
 * */

 function manduca_get_hungarian_definite_article( $word ) {
	
	//only works if the language is Hungarian 
	if ( get_locale() ==='hu_HU' ) {
		$hungarian_regex = '/^[aáeéiíoóöőuúüű]/i';
		if (preg_match ( $hungarian_regex, $word ) ) {
			$article = 'az';	
		}
		else {
			$article = 'a';
		}
	}
	return $article;
 }
 

if( !function_exists( 'manduca_content_more_link' ) ) :
	function manduca_content_more_link() {
		$svg = manduca_get_svg( array( 'icon' => 'angle-right' ) ) ;
		$content_more_link = sprintf( '<a href="%1$s" class="more-link color-2" id="continue-reading-%2$s" aria-labelledby="post-%2$s" >%3$s %4$s</a>',
									get_permalink(),
									get_the_ID(),
									__( 'Continue reading', 'manduca' ),
									$svg
								   );
		return $content_more_link;
	}
endif;
	
/*
 *Display continue reading link
 **/

function manduca_the_content_more_link() {
	echo manduca_content_more_link();
}

add_filter( 'the_content_more_link', 'manduca_content_more_link' );
add_filter( 'excerpt_more', 'manduca_content_more_link' );


/*
 * add read-more link to manual excerpt
 * */
function manduca_manual_excerpt ( $excerpt ) {
	global $post;
	if( $post->post_excerpt ) {
		return $excerpt .manduca_content_more_link();
	} else {
		return $excerpt;
	}
}

add_filter('get_the_excerpt', 'manduca_manual_excerpt');





/*
* Get domain name from url 
*
* @parameter string $uri URI of to be analized 
* */

function manduca_get_domain_name_from_uri( $uri ) {
	preg_match( '/^(http:\/\/)?([^\/]+)/i', $uri, $matches );
	$host = $matches[2];
	preg_match( '/[^\.\/]+\.[^\.\/]+$/', $host, $matches );
	return $host;
}


/* callback function of preg_replace to parse links
 *
 * @param $matches HTML code to filter
 *
 * @return modified HTML code, where class="ext-links" are added. 
 *
 * */

function mandcua_parse_links( $matches ) {

	//echo 'debug #link-functions#103<br><pre>'; print_r( $matches ); echo '</pre>';

	if ( ! isset( $matches[2][0] )  ) {
		$anchor_link = true;
		//echo 'true';
		
	}
	elseif( $matches[2][0] !=='#') {
		$anchor_link = false;
		//echo 'false';
	}
	else {
		$anchor_link = false;
		//echo 'false';
	}
	
	// If the link has img in it, add class="image-link".
	if( strpos( $matches[5], 'img' ) !== false ) {
			
			$matches = manduca_append_class_to_html( $matches , 'image-link' );
			$matches [4] .= 'aria-label="' .__( 'include image', 'manduca' ) .'" ';
			
			$pattern = manduca_construct_anchor ( $matches, '' );
		
	}
	
	// If it is an external link	
	elseif ( manduca_get_domain_name_from_uri( $matches[3] ) != manduca_get_domain_name_from_uri( $_SERVER["HTTP_HOST"] ) &&  $anchor_link ) {
		
		
		$matches = manduca_append_class_to_html( $matches , 'ext-link' );
		$matches [4] .= 'aria-label="' .__( 'external', 'manduca' ) .'" ';
		
		$pattern = manduca_construct_anchor ( $matches, manduca_get_svg( array( 'icon' => 'extlink') ) );
		
	
	}
	
	//It is not an external link
	else {
		
		// If Word document
			
		if( strpos( $matches[3], 'docx' ) !== false || strpos( $matches[3], 'doc' ) !== false  ) {
			
			$matches = manduca_append_class_to_html( $matches , 'media' );
			$matches [4] .= 'aria-label="' .__( 'MS Word document', 'manduca' ) .'" ';
			$pattern = manduca_construct_anchor ( $matches, manduca_get_svg( array( 'icon' => 'word') ) );
		
		}
		elseif( strpos( $matches[3], 'xlsx' ) !== false || strpos( $matches[3], 'xls' ) !== false  ) {
		
			$matches = manduca_append_class_to_html( $matches , 'media' );
			$matches [4] .= 'aria-label="' .__( 'MS Excel document', 'manduca' ) .'" ';
			$pattern = manduca_construct_anchor ( $matches, manduca_get_svg( array( 'icon' => 'excel') ) );
		
		}
		elseif( strpos( $matches[3], 'pdf' ) !== false ) {
		
			$matches = manduca_append_class_to_html( $matches , 'media' );
			$matches [4] .= 'aria-label="' .__( 'PDF document', 'manduca' ) .'" ';
			$pattern = manduca_construct_anchor ( $matches, manduca_get_svg( array( 'icon' => 'pdf') ) );
		
		}
		else {
		
			$pattern = manduca_construct_anchor ( $matches, '' );
		
		}
	
	//end of not external link branch	
	}
	
	
	return $pattern;
}

/**
 * Append HTMl class to the HTMl tokens
 *
 * @param array: tokens of link
 * @param class: class to be appended.
 *
 *  @return array: appended with class
 * @since 17.9.7
 *
 **/

 function manduca_append_class_to_html( $tokens, $class ) {
	$flag = FALSE ;
		
			if( !empty ($tokens[4]) ) {
				
				if ( strpos( $tokens[4], 'class=') !== FALSE  ) {
					$tokens[4] = str_replace ( 'class="', 'class="' .$class .' ', $tokens[4]);
					$flag = TRUE;
				}
			}
		
		//If there is no class attribute. 
		if ( !$flag ) {
			$tokens[4] .= 'class="' .$class .'" ';
		}
		return $tokens;
 }
 

/**
 * Construct anchor (<a>) link of media links and adds an icon
 *
 * @param array $tokens parts of the anchor link
 * @param array $tokens parts of the anchor link
 *
 * @return HTML element
 *
 * @since 17.9.7
 * */
	
function manduca_construct_anchor( $tokens, $svg ) {
	return sprintf ( '<a href="%1$s//%2$s" %3$s %4$s>%5$s%6$s</a>',
							   $tokens[2],
							   $tokens[3],
							   $tokens[1],
							   $tokens[4],
							   $tokens[5],
							   $svg
							   );
}

/*
 * Categorize links to add svg and class after it. 
 **/
function manduca_categorize_links( $text ) {
	$pattern = '/<a (.*?)href="(.*?)\/\/(.*?)"(.*?)>(.*?)<\/a>/i';
	$text = preg_replace_callback( $pattern, 'mandcua_parse_links', $text );
	return $text;
}


// filters have high priority to make sure that any markup plugins like Textile or Markdown have already created the HTML links
add_filter( 'the_content', 'manduca_categorize_links', 999 );
add_filter( 'the_excerpt', 'manduca_categorize_links', 999 );
add_filter( 'comment_text', 'manduca_categorize_links', 999 );
add_filter( 'widget_text', 'manduca_categorize_links', 999 );

?>