<?php
/**
 * Navigation functions
 *
 * Package Manduca
 *
 * @since 17.9
 * */

 
/**
 * Displays paginated link for post pages in the format of serial numbers (e.g. '11-20' ).
 * Shows all links. 
 *
 * @since 16.7
 * Manduca replaces wp_list_pages() with this function. 
 *
 * @global WP_Query   $wp_query
 * @global WP_Rewrite $wp_rewrite
 *
 */
	
if ( ! function_exists( 'manduca_page_navigation' ) ) :
 
	function manduca_page_navigation() {
		$left_arrow = manduca_get_svg( array( 'icon' => 'angle-circle-left') );
		$right_arrow = manduca_get_svg( array( 'icon' => 'angle-circle-right') );
		?>
		<nav class="nav-single">
		
			<?php
			$previous_post	= get_previous_post_link(  '%link', $left_arrow . '<span>%title</span>' );
			$next_post		= get_next_post_link( '%link', '<span>%title</span>' .$right_arrow );
				if( !empty( $previous_post ) ) : ?>
				<div class="nav-previous">
					<p class="assistive-text"><?php _e( 'Previous post', 'manduca' ) ?></p>
					
					<?php  echo $previous_post; ?>
					<?php paginate_links(); //the sake of themecheck.  I.e. there is no need for that but theme check requires it. ?>
				</div>
				
				<?php endif;
				
				
				if( !empty( $next_post ) ) : ?>
				<div class="nav-next">
					<p class="assistive-text"><?php _e( 'Next post', 'manduca' ) ?></p>
					
					<?php echo $next_post; ?>
					
				</div>
				<?php endif;
			?>
		
			</nav><!-- .nav-single -->

		<?php
	}
endif;



/*
 * Get the post navigation all pages
 * All the posts in the query using numbers to navigate between pages. 
 *
 * @since 17.3
 * */

	if( !function_exists( 'manduca_get_post_pagination') ) :
	   
	   function manduca_get_post_pagination() {
		   
		   $arrow_right_svg = manduca_get_svg( array( 'icon' => 'angle-right' ) ) ;
		   $arrow_left_svg = manduca_get_svg( array( 'icon' => 'angle-left' ) ) ;;
		   $nav = get_the_posts_pagination( array(
			   'prev_text' => $arrow_left_svg .'<span class="screen-reader-text">' . __( 'Newer posts', 'manduca' ) .'</span>'		,
			   'next_text' => '<span class="screen-reader-text">' .__( 'Older posts', 'manduca' ) .'</span>' . $arrow_right_svg,
			   'before_page_number' => '<span class="screen-reader-text">' . __( 'page', 'manduca' ) . ' </span>'
	   ) );	
			return $nav;
	}
endif;



/*
* Change template and class of WP core's post navigation function
*
* Reason: role="navigation" and h2 should be is removed from markup
*
* @since 17.9
* */
function manduca_post_navigation_markup( $template, $class ) {
	
	 $template='<nav class="navigation %1$s">
        <div class="nav-links">%3$s</div>
    </nav>';
	
	return $template;
}

add_filter( 'navigation_markup_template', 'manduca_post_navigation_markup', 10, 2);




?>
