<?php
/**
 * Template functions
 *
 * Package Manduca
 *
 * @since 17.7
 * */


if ( ! isset( $content_width ) ) {
	$content_width = 625;
}
 
 
/*
* Get custom header's alt data.
* 
*/
function manduca_get_header_image_alt() {
    $attachment_id = 0;
    
    if ( is_random_header_image() && $header_url = get_header_image() ) {
	    // For a random header, we have to search for a match against all headers.
	    foreach ( get_uploaded_header_images() as $header ) {
		    if ( $header['url'] == $header_url ) {
			    $attachment_id = $header['attachment_id'];
			    break;
		    }
	    }
    
    } elseif ( $data = get_custom_header() ) {
	    // For static headers, less intensive approach.
	    $attachment_id = $data->attachment_id;
    } 
    
    if ( $attachment_id ) {
	    $alt = trim( strip_tags( get_post_meta( $attachment_id, '_wp_attachment_image_alt', true ) ) );

	    if ( ! $alt ) {
		    $alt = trim( strip_tags( get_post_field( 'post_excerpt', $attachment_id ) ) );
	    }
	    if ( ! $alt ) {
		    $alt = trim( strip_tags( get_post_field( 'post_title', $attachment_id ) ) );
	    }
    }
	else {
	    $alt = '';
    }
    
    return $alt;
}


/*
 * Set body classes
 *
 * @since 1.0
 * */

function manduca_body_class( $classes , $extra_classes ) {
	$background_color = get_background_color();
	$background_image = get_background_image();
	
	// List of the only WP generated classes allowed
    $whitelist = array( 'home', 'error404', 'page' );

    // Filter the body classes
    $classes = array_intersect( $classes, $whitelist );

	// Add the extra classes back untouched	
	$classes = array_merge( $classes, (array) $extra_classes );	
	
	
	if ( is_page_template( 'page-templates/full-width.php' )  ) {
		$classes[] = 'full-width';
	}
	else {
		$classes[] = 'two-columns';
	}

	if ( empty( $background_image ) ) {
		if ( empty( $background_color ) ) {
			$classes[] = 'custom-background-empty';
		}
		elseif ( in_array( $background_color, array( 'fff', 'ffffff' ) ) ) {
			$classes[] = 'custom-background-white';
		}
	}

	if ( ! is_multi_author() ) {
		$classes[] = 'single-author';
	}
	
	$classes = array_merge( $classes, manduca_is_firefox( $classes ) ) ;
	
	return $classes; 
}
add_filter( 'body_class', 'manduca_body_class', 10 , 2  );

 
 /*
 * Plugin name: Detect visitors browser and add to body tag	
 *
 * https://www.smashingmagazine.com/2009/08/10-useful-wordpress-hook-hacks/
 *
 * */

function manduca_is_firefox( $classes) {
  global $is_gecko;
	
	if( $is_gecko ) {
		$classes[] = 'firefox';
	}
	
  return $classes;
}
 
 
 
  
//-------------------------------------------------------------------------------------------
// Avatar need alt tag
//-------------------------------------------------------------------------------------------

    
function manduca_add_alt_to_avatar( $text )
{
	$alt = get_the_author_meta( 'display_name' );
	$text = str_replace( 'alt=""', 'alt="'.$alt . __( 'avatar', 'manduca' ) , $text );
	return $text;
}
add_filter( 'get_avatar', 'manduca_add_alt_to_avatar' );




/**
 * Change HTML headings
 * 
 * */

if( !function_exists( 'manduca_heading_correction' ) ) :

	function manduca_heading_correction ( $content ) {
		if ( is_archive() ) {
			$content = str_replace( '<h4>', '<h5>', $content );
			$content = str_replace( '</h4>', '</h5>', $content );
			$content = str_replace( '<h3>', '<h4>', $content );
			$content = str_replace( '</h3>', '</h4>', $content );
			$content = str_replace( '<h2>', '<h3>', $content );
			$content = str_replace( '</h2>', '</h3>', $content );
		}
		return $content;
	}

	add_filter( 'the_content', 'manduca_heading_correction' );

endif;


 
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @since 17.7.
 */

if ( ! function_exists( 'manduca_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function manduca_posted_on() {

	// Get the author name; wrap it in a link.
	$byline = sprintf(
		/* translators: %s: post author */
		__( 'by %s', 'manduca' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . get_the_author() . '</a></span>'
	);

	// Finally, let's write all of this to the page.
	echo '<span class="posted-on">' . manduca_time_link() . '</span><span class="byline"> ' . $byline . '</span>';
}
endif;


if ( ! function_exists( 'manduca_time_link' ) ) :
/**
 * Gets a nicely formatted string for the published date.
 */
function manduca_time_link() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		get_the_date( DATE_W3C ),
		get_the_date(),
		get_the_modified_date( DATE_W3C ),
		get_the_modified_date()
	);

	// Wrap the time string in a link, and preface it with 'Posted on'.
	return sprintf(
		/* translators: %s: post date */
		__( '<span class="screen-reader-text">Posted on</span> %s', 'manduca' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);
}
endif;


/*
 *Displays entry meta data
 **/

if ( ! function_exists( 'manduca_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function manduca_entry_footer() {

	/* translators: used between list items, there is a space after the comma */
	$separate_meta = __( ', ', 'manduca' );

	// Get Categories for posts.
	$categories_list = get_the_category_list( $separate_meta );

	// Get Tags for posts.
	$tags_list = get_the_tag_list( '', $separate_meta );

	// We don't want to output .entry-footer if it will be empty, so make sure its not.
	if ( ( ( manduca_categorized_blog() && $categories_list ) || $tags_list ) || get_edit_post_link() ) {

		echo '<footer class="entry-footer">';

			if ( 'post' === get_post_type() ) {
				if ( ( $categories_list && manduca_categorized_blog() ) || $tags_list ) {
					echo '<span class="cat-tags-links">';

						// Make sure there's more than one category before displaying.
						if ( $categories_list && manduca_categorized_blog() ) {
							echo '<span class="cat-links">' . manduca_get_svg( array( 'icon' => 'folder-open' ) ) . '<span class="screen-reader-text">' . __( 'Categories', 'manduca' ) . '</span>' . $categories_list . '</span>';
						}

						if ( $tags_list ) {
							echo '<span class="tags-links">' . manduca_get_svg( array( 'icon' => 'hashtag' ) ) . '<span class="screen-reader-text">' . __( 'Tags', 'manduca' ) . '</span>' . $tags_list . '</span>';
						}

					echo '</span>';
				}
			}

			manduca_edit_post_link();

		echo '</footer> <!-- .entry-footer -->';
	}
}
endif;


if ( ! function_exists( 'manduca_edit_post_link' ) ) :
/**
 * Displays an accessibility-friendly link to edit a post or page.
 *
 * This also gives us a little context about what exactly we're editing
 * (post or page?) so that users understand a bit more where they are in terms
 * of the template hierarchy and their content. Helpful when/if the single-page
 * layout with multiple posts/pages shown gets confusing.
 *
 * @since 17.9
 */
function manduca_edit_post_link() {
	$svg= manduca_get_svg ( array( 'icon' => 'pencil' ) );
	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			__( 'Edit', 'manduca' ) .'<span class="screen-reader-text"> "%s"</span>',
			get_the_title()
		),
		'<span class="edit-link">' .$svg,
		'</span>'
	);
}
endif;



/*
 *Add anchor to image anchor insert in post content
 *
 *@since 16.10
 *
 */


function manduca_add_class_image_anchor($html, $id, $caption, $title, $align, $url, $size, $alt = '' ){
  $classes = 'image-link'; 

  if ( preg_match('/<a.*? class=".*?">/', $html) ) {
    $html = preg_replace('/(<a.*? class=".*?)(".*?>)/', '$1 ' . $classes . '$2', $html);
  } else {
    $html = preg_replace('/(<a.*?)>/', '$1 class="' . $classes . '" >', $html);
  }
  return $html;
}
add_filter('image_send_to_editor','manduca_add_class_image_anchor',10,8);

 
/*
 *Display excerpt with navigation bar
 *
 * @since 17.1
 **/
if( !function_exists( 'manduca_display_excerpt' ) ) :
 
	function manduca_display_excerpt() {

		$nav = manduca_get_post_pagination(); ?>
			
		<?php echo $nav; ?>
				
		
		<div class="excerpt-wrapper" id="entry-content">

			<?php while ( have_posts() ) : the_post();  ?>
		
				<?php get_template_part( 'template-parts/posts/content', 'excerpt' ); ?>
		
			<?php endwhile; ?>
		
		</div>
	
		<?php echo $nav; 

	}

endif;


/*
 * register Manduca's sidebar
 *
 * @ since 1.0
 **/
		
function manduca_widgets_init() {
		register_sidebar( array(
			'name' =>__( 'Sidebar', 'manduca' ),
			'id' => 'main_sidebar',
			'description' => __( 'Appears all pages except when using full page template', 'manduca' ),
			'before_widget' => '<section id="%1$s" class="widget accessible-content %2$s">',
			'after_widget' => '</div></section>',
			'before_title' => '<h2 class="widget-title">',
			'after_title' =>'</h2><div class="widget-content">',
		) );
}
add_action( 'widgets_init', 'manduca_widgets_init' );


/*
 * Remove gallery inline style
 *
 * @since 17.1
 * */
add_filter( 'use_default_gallery_style', '__return_false' );
 

 
?>