<?php
/** 
 * Functions related to pages
 *
 *
 * @ Theme: Manduca - focus on accessibility
 * @ since 17.9.17
 **/

Class page_functions {
	
	/**
	 * Retreives the content of the page 404
	 * If page-notfound.php page template has posts in it, it applies.
	 * otherwise return the default content.
	 *
	 * @return array string title
	 * 				 string content
	 *
	 * @since 17.9.18
	 * */
	
	public function page_not_found() {
		
		$args = array(
							'post_type' => 'page',
							'posts_per_page' => 1,
							'meta_query' => array(
								array(
									'key' => '_wp_page_template',
									'value' => 'page-templates/page-notfound.php'
								)
							)
						);
		$the_pages = new WP_Query( $args );
							
		if( $the_pages->have_posts() ){
				
				$the_pages->the_post();
				$title 		= the_title( '', '', false );
				$content  	= get_the_content();
				$content	= apply_filters( 'the_content', $content );
		}
		else{
			$title 		= __( 'Error 404 &#45; Page Not Found!', 'manduca' );
			$content 	= __( 'The requested page could not be located on this blog. We highly recommend to choose from the HTML sitemap below.', 'manduca' ) ;
		}
		
		$article = array(
				'title' 	=> $title,
				'content' 	=> $content
				);

		return $article;
	}
	
	
	/*
	 * Displays header of page
	 * add css class=thumbnail when page has thumbnail
	 *
	 * called from: content-page.php
	 *
	 * @since 17.9.17
	 *
	 * */
	public function page_header() {
			if ( has_post_thumbnail() ) {
				$class = 'has-thumbnail'; 
			}
			else{
				$class = 'no-thumbnail';
			}

			printf( '<header class="%1$s"><h1 class="color-4">%2$s</h1>',
				   $class,
				   get_the_title()
				   );
			
			if ( has_post_thumbnail() ) {
				printf( '<div>%s</div>',
					   get_the_post_thumbnail( null, 'post-size' )
					   );
			}
			
			echo '</header>';
	}
	
}
 
	
