<?php
/**
 * Add action and filter hooks to WordPress
 *
 * @ Theme: Manduca - focus on accessibility
 * @ since 17.9.16
 *
 * */

Class theme_setup {
	
	public function __construct () {
		
		add_action( 'after_setup_theme', array(
							$this,
							'mixed_setup'
							)
				);
		add_action( 'after_setup_theme', array(
							$this,
							'image_size_settings'
							)
				);

		add_filter( 'intermediate_image_sizes_advanced', array(
							$this,
							'delete_default_image_sizes'
							)
				);

		add_filter( 'image_size_names_choose', array(
							$this,
							'filter_image_sizes'
							)
				);
		
		add_filter( 'body_class', array(
							$this,
							'identify_firefox'
							)
				);
		
		
		$this->disable_jpg_compression();
	}

 
	/*
	 * Register the themes main parameters: 
	 * Nav menus, theme support, editor style, textdomain
	 **/
	public function mixed_setup() {
		// Styles the visual editor with editor-style.css
		add_editor_style();
		
		// Adds RSS feed links to <head> for posts and comments.
		add_theme_support( 'automatic-feed-links' );
		
		// Switch default core markup to output valid HTML5.
		add_theme_support( 'html5', array(
			'search-form', 'comment-form', 'comment-list', 'caption', 'gallery'
		) );
		
		//Allows themes to add document title tag
		add_theme_support( 'title-tag' );
		
		//Register navigation menus
		register_nav_menu( 'primary', __( 'Main navigation', 'manduca' ) );
		register_nav_menu( 'footer', __( 'Footer navigation', 'manduca' ) );
		
		//Makes translation-ready
		load_theme_textdomain( 'manduca', get_template_directory() . '/assets/lang' );
		
		
		 //Supports custom background color and image
		add_theme_support( 'custom-background', array(
			'default-color' => 'f3f3f5',
		) );
		
	}
	
	/*
	 * 3 images sizes needed: 
	 **/
	public function image_size_settings() {
		// Uses a custom image size for featured images
		add_theme_support( 'post-thumbnails' );
		add_image_size ('post-size', 890, 592 );
		add_image_size ('excerpt-size', 268, 178 );
		
		//Change the default image sizes to zero 
		update_option( 'medium_size_w', 0 );
		update_option( 'medium_size_h', 0 );
		update_option( 'large_size_w', 0 );
		update_option( 'large_size_h', 0 );
		
	}
	
	
	
	/*
	 * Disable jpg compression
	 **/
	public function disable_jpg_compression() {
		add_filter('jpeg_quality', create_function('', 'return 100;'));
		add_filter('wp_editor_set_quality', create_function('', 'return 100;'));
	}
	
	
		
	/**
	* Delete WordPress default image sizes
	* Do not need to waste HD capacity for those image sizes. 
	**/
	public function delete_default_image_sizes( $sizes ) {
		unset( $sizes[ 'large' ] );
		unset( $sizes[ 'medium_large' ] );
		return $sizes;
	}
	
	
	
	/*
	* Change name of Manduca specific image sizes
	**/
   function image_size_names( $sizes ) {
	   $add_sizes = array(
		   'thumbnail-size' 	=> __( 'Thumbnail', 'manduca' ),
		   'post-size' 			=> __( 'Image in Post', 'manduca' ),
		   'full' 				=> __( 'Original size', 'manduca' )
	   );
	   $new_sizes = array_merge($sizes, $add_sizes);
	   return $new_sizes;
	}
	
	
	/*
	 * Identify if Firefox is used, and set a body class for that
	 * */
	function identify_firefox ( $classes ) {
		global $is_gecko;
		if($is_gecko) $classes[] = 'gecko';
		return $classes;
	}
		
}

?>